@@ -26,48 +26,46 @@
 
 #include "settings.h"
 
-#include <KDebug>
-
 #include <QDesktopWidget>
 
 static const QStringList keymaps = (QStringList()
-    << "ar"
-    << "cs"
-    << "da"
-    << "de"
-    << "de-ch"
-    << "en-dv"
-    << "en-gb"
-    << "en-us"
-    << "es"
-    << "et"
-    << "fi"
-    << "fo"
-    << "fr"
-    << "fr-be"
-    << "fr-ca"
-    << "fr-ch"
-    << "he"
-    << "hr"
-    << "hu"
-    << "is"
-    << "it"
-    << "ja"
-    << "ko"
-    << "lt"
-    << "lv"
-    << "mk"
-    << "nl"
-    << "nl-be"
-    << "no"
-    << "pl"
-    << "pt"
-    << "pt-br"
-    << "ru"
-    << "sl"
-    << "sv"
-    << "th"
-    << "tr"
+    << QStringLiteral("ar")
+    << QStringLiteral("cs")
+    << QStringLiteral("da")
+    << QStringLiteral("de")
+    << QStringLiteral("de-ch")
+    << QStringLiteral("en-dv")
+    << QStringLiteral("en-gb")
+    << QStringLiteral("en-us")
+    << QStringLiteral("es")
+    << QStringLiteral("et")
+    << QStringLiteral("fi")
+    << QStringLiteral("fo")
+    << QStringLiteral("fr")
+    << QStringLiteral("fr-be")
+    << QStringLiteral("fr-ca")
+    << QStringLiteral("fr-ch")
+    << QStringLiteral("he")
+    << QStringLiteral("hr")
+    << QStringLiteral("hu")
+    << QStringLiteral("is")
+    << QStringLiteral("it")
+    << QStringLiteral("ja")
+    << QStringLiteral("ko")
+    << QStringLiteral("lt")
+    << QStringLiteral("lv")
+    << QStringLiteral("mk")
+    << QStringLiteral("nl")
+    << QStringLiteral("nl-be")
+    << QStringLiteral("no")
+    << QStringLiteral("pl")
+    << QStringLiteral("pt")
+    << QStringLiteral("pt-br")
+    << QStringLiteral("ru")
+    << QStringLiteral("sl")
+    << QStringLiteral("sv")
+    << QStringLiteral("th")
+    << QStringLiteral("tr")
 );
 
 static const int defaultKeymap = 7; // en-us
@@ -100,24 +98,28 @@ QWidget* RdpHostPreferences::createProtocolSpecificConfigPage()
     QWidget *rdpPage = new QWidget();
     rdpUi.setupUi(rdpPage);
 
+    connect(rdpUi.kcfg_Sound, SIGNAL(currentIndexChanged(int)), SLOT(updateSoundSystem(int)));
+
     rdpUi.loginGroupBox->setVisible(false);
 
     rdpUi.kcfg_Height->setValue(height());
     rdpUi.kcfg_Width->setValue(width());
+    rdpUi.kcfg_Resolution->setCurrentIndex(resolution());
     rdpUi.kcfg_ColorDepth->setCurrentIndex(colorDepth());
     rdpUi.kcfg_KeyboardLayout->setCurrentIndex(keymap2int(keyboardLayout()));
     rdpUi.kcfg_Sound->setCurrentIndex(sound());
+    rdpUi.kcfg_SoundSystem->setCurrentIndex(soundSystem());
     rdpUi.kcfg_Console->setChecked(console());
     rdpUi.kcfg_ExtraOptions->setText(extraOptions());
     rdpUi.kcfg_RemoteFX->setChecked(remoteFX());
     rdpUi.kcfg_Performance->setCurrentIndex(performance());
     rdpUi.kcfg_ShareMedia->setText(shareMedia());
 
-    connect(rdpUi.resolutionComboBox, SIGNAL(currentIndexChanged(int)), SLOT(updateWidthHeight(int)));
+    // Have to call updateWidthHeight() here
+    // We leverage the final part of this function to enable/disable kcfg_Height and kcfg_Width
+    updateWidthHeight(resolution());
 
-    const QString resolutionString = QString::number(width()) + 'x' + QString::number(height());
-    const int resolutionIndex = rdpUi.resolutionComboBox->findText(resolutionString, Qt::MatchContains);
-    rdpUi.resolutionComboBox->setCurrentIndex((resolutionIndex == -1) ? rdpUi.resolutionComboBox->count() - 2 : resolutionIndex); // - 2 is index of custom resolution
+    connect(rdpUi.kcfg_Resolution, SIGNAL(currentIndexChanged(int)), SLOT(updateWidthHeight(int)));
 
     return rdpPage;
 }
@@ -169,15 +171,34 @@ void RdpHostPreferences::updateWidthHeight(int index)
     rdpUi.widthLabel->setEnabled(enabled);
 }
 
+void RdpHostPreferences::updateSoundSystem(int index)
+{
+    switch (index) {
+    case 0: /* On This Computer */
+        rdpUi.kcfg_SoundSystem->setCurrentIndex(soundSystem());
+        rdpUi.kcfg_SoundSystem->setEnabled(true);
+        break;
+    case 1: /* On Remote Computer */
+    case 2: /* Disable Sound */
+        rdpUi.kcfg_SoundSystem->setCurrentIndex(2);
+        rdpUi.kcfg_SoundSystem->setEnabled(false);
+        break;
+    default:
+        break;
+    }
+}
+
 void RdpHostPreferences::acceptConfig()
 {
     HostPreferences::acceptConfig();
 
     setHeight(rdpUi.kcfg_Height->value());
     setWidth(rdpUi.kcfg_Width->value());
+    setResolution(rdpUi.kcfg_Resolution->currentIndex());
     setColorDepth(rdpUi.kcfg_ColorDepth->currentIndex());
     setKeyboardLayout(int2keymap(rdpUi.kcfg_KeyboardLayout->currentIndex()));
     setSound(rdpUi.kcfg_Sound->currentIndex());
+    setSoundSystem(rdpUi.kcfg_SoundSystem->currentIndex());
     setConsole(rdpUi.kcfg_Console->isChecked());
     setExtraOptions(rdpUi.kcfg_ExtraOptions->text());
     setRemoteFX(rdpUi.kcfg_RemoteFX->isChecked());
@@ -185,6 +206,17 @@ void RdpHostPreferences::acceptConfig()
     setShareMedia(rdpUi.kcfg_ShareMedia->text());
 }
 
+void RdpHostPreferences::setResolution(int resolution)
+{
+    if (resolution >= 0)
+        m_configGroup.writeEntry("resolution", resolution);
+}
+
+int RdpHostPreferences::resolution() const
+{
+    return m_configGroup.readEntry("resolution", Settings::resolution());
+}
+
 void RdpHostPreferences::setColorDepth(int colorDepth)
 {
     if (colorDepth >= 0)
@@ -218,6 +250,17 @@ int RdpHostPreferences::sound() const
     return m_configGroup.readEntry("sound", Settings::sound());
 }
 
+void RdpHostPreferences::setSoundSystem(int sound)
+{
+    if (sound >= 0)
+        m_configGroup.writeEntry("soundSystem", sound);
+}
+
+int RdpHostPreferences::soundSystem() const
+{
+    return m_configGroup.readEntry("soundSystem", Settings::soundSystem());
+}
+
 void RdpHostPreferences::setConsole(bool console)
 {
     m_configGroup.writeEntry("console", console);
